@@ -11,7 +11,7 @@ class TelegramSender(Sender):
         self.bot = Bot(token=DI.get_tg_bot_token())
         self.chat_id = chat_id if chat_id else DI.get_tg_chat_id()
 
-    def send_message(self, message: str | list) -> None:
+    def send_message(self, message: str) -> None:
         self.bot.sendMessage(chat_id=self.chat_id, text=message)
 
     def send_image(self, image_path: str) -> None:
